Set Sparsity Tuning Parameter
setSparsityParameter.RdAssigns a sparsity tuning parameter to an object of class rdClass, fdClass, imgClass, or hdClass.
Details
This function returns a modified version of the input object with an updated "Sparsity_parameter" attribute.
Due to R's copy-on-modify semantics for S3 objects, the user must reassign the object:
obj <- setSparsityParameter(obj, c(0, 2, 4))The object will not be updated in-place unless reassigned.