Compute Scaling Weights for hdClass Object
scale_hd.RdThis function computes scaling weights for each component (column) in a hdClass object.
The goal is to normalize the contributions of different functional variables by
accounting for their scale, using the inverse of total variance (integrated over domain).